@@ -9,7 +9,7 @@ use strict;
 package Authen::PluggableCaptcha::Render::Image;
 use vars qw(@ISA $VERSION);
 $VERSION= '0.01';
-use Authen::PluggableCaptcha::Render;
+use Authen::PluggableCaptcha::Render ();
 our @ISA= qw( Authen::PluggableCaptcha::Render );
 
 ######################################################
