@@ -14,7 +14,7 @@ our @ISA= qw( Authen::PluggableCaptcha::Render::Image::Imager::layers );
 
 ######################################################
 
-use Imager;
+use Imager ();
 
 ######################################################
 
