@@ -29,8 +29,8 @@ Authen::PluggableCaptcha::Tutorial - How to use the Captcha System
 	);
 
 	my $as_string= $captcha->render( 
-		challenge=> 'Authen::PluggableCaptcha::Challenge::TypeString', 
-		render=>'Authen::PluggableCaptcha::Render::Image::Imager' ,  
+		challenge_class=> 'Authen::PluggableCaptcha::Challenge::TypeString', 
+		render_class=>'Authen::PluggableCaptcha::Render::Image::Imager' ,  
 		font_filename=> '/usr/X11R6/lib/X11/fonts/TTF/VeraMoIt.ttf',
 		format=>'jpeg' 
 	);
@@ -54,8 +54,8 @@ again, create a new object
 render it
 
 	my 	$as_string= $captcha->render( 
-			challenge=> 'Authen::PluggableCaptcha::Challenge::DoMath', 
-			render=>'Authen::PluggableCaptcha::Render::Text::HTML' 
+			challenge_class=> 'Authen::PluggableCaptcha::Challenge::DoMath', 
+			render_class=>'Authen::PluggableCaptcha::Render::Text::HTML' 
 		);
 
 now you can serve it directly, or write it-- its just html text.  
@@ -82,15 +82,15 @@ create an object
 run the validation 1x through, just so we get the vars set up and can pull the correct_response for the success
 
 	my 	$i_doubt_this_will_work= $captcha->validate_response( 
-			challenge=> 'Authen::PluggableCaptcha::Challenge::TypeString' , 
+			challenge_class=> 'Authen::PluggableCaptcha::Challenge::TypeString' , 
 			user_response=>'a' 
 		) ? "yes" : "no" ;
 
 then we can toss in the correct response
 
 	my 	$success= $captcha->validate_response( 
-			challenge=> 'Authen::PluggableCaptcha::Challenge::TypeString' , 
-			user_response=>$captcha->{'__Challenge'}{'Authen::PluggableCaptcha::Challenge::TypeString'}{'correct_response'} 
+			challenge_class=> 'Authen::PluggableCaptcha::Challenge::TypeString' , 
+			user_response=>$captcha->challenge_object->('Authen::PluggableCaptcha::Challenge::TypeString')->correct_response
 		) ? "yes" : "no" ;
 
 =head2 A real-world implementation
@@ -180,8 +180,8 @@ to show a text captcha, we can render this directly into a Petal document
 		'Captcha'=> {
 			instructions=> undef,
 			user_prompt=> $self->{'CaptchaInstance'}->render( 
-				challenge=> 'Authen::PluggableCaptcha::Challenge::DoMath', 
-				render=>'Authen::PluggableCaptcha:::Render::Text::HTML' 
+				challenge_class=> 'Authen::PluggableCaptcha::Challenge::DoMath', 
+				render_class=>'Authen::PluggableCaptcha:::Render::Text::HTML' 
 			),
 		},
 	);
@@ -192,7 +192,7 @@ make sure we called the init already
 
 	if 	(
 			!$self->{'CaptchaInstance'}->validate_response(
-				challenge=> 'Authen::PluggableCaptcha::Challenge::DoMath',
+				challenge_class=> 'Authen::PluggableCaptcha::Challenge::DoMath',
 				user_response=> $self->{'Form'}->get_validated('captcha_response'),
 			)
 		) {
@@ -224,8 +224,8 @@ if the captcha generator were locked into a page, then you could just hardcode t
 	
 		$self->{'PageUser'}{'ApacheRequest'}->content_type('image/jpeg');
 		$self->{'__BODY'}= $self->{'CaptchaInstance'}->render( 
-			challenge=> 'Authen::PluggableCaptcha::Challenge::TypeString', 
-			render=>'Authen::PluggableCaptcha::Render::Image::Imager' ,  
+			challenge_class=> 'Authen::PluggableCaptcha::Challenge::TypeString', 
+			render_class=>'Authen::PluggableCaptcha::Render::Image::Imager' ,  
 			font_filename=> '/usr/X11R6/lib/X11/fonts/TTF/VeraMoIt.ttf',
 			format=>'jpeg' 
 		);
@@ -236,21 +236,19 @@ if the captcha generator were locked into a page, then you could just hardcode t
 
 =head2 FAQ
 
-=head3 It somewhat tickles in my estheticle that there is a new
-constructor for both new and existing CAPTCHAs, and I don't quite
-understand why you do it that way?
+=head3 It somewhat tickles in my estheticle that there is a new constructor for both new and existing CAPTCHAs, and I don't quite understand why you do it that way?
 
 There is a single constructer that 'forks' into 2 separate init routines based on an argument to new().
 
-The type='new' routine just creates a new KeyGenerator instance and runs the code necessary to generate a new public_key ( which could conceivably be a little resource intensive, if you've created a module that hits a db to check for colliisions).  The fork was an obvious solution to split unnecessary calls out for performance optimization (ie: only run what you need )
+The type='new' routine just creates a new KeyManager instance and runs the code necessary to generate a new public_key ( which could conceivably be a little resource intensive, if you've created a module that hits a db to check for colliisions).  The fork was an obvious solution to split unnecessary calls out for performance optimization (ie: only run what you need )
 
 The type='existing' routine automatically validates the construction arguments, which is unnecessary for new captchas.
 
-Originally there was a single 'new', and from that you could call either 'new()' or 'existing()' arguments -- but then I realized that people like 1 line of code.
+Originally there was a single 'new', and from that you could call either 'new()' or 'existing()' -- but more people like 1 line of code.
 
 =head3 Does it really need to know the site secret and seed for an existing CAPTCHA? Intuitively, I would think that it is only needed for a new CAPTCHA, and that only the public keys should be needed for an existing CAPTCHA?
 
-That depends on how the KeyGenerator class you specify uses the site_secret to validate the key (which is why site_secret is not required in the base class )
+That depends on how the KeyManager class you specify uses the site_secret to validate the key (which is why site_secret is not required in the base class )
 
 For example:
 
@@ -259,26 +257,30 @@ For example:
 
 If we know the site_secret under that formula, we always have every components of the item at our disposal -- and can validate the key for integrity
 
+The default KeyManager class uses a site_secret to create the key.
+
 =head3 Also, from the example in the Tutorial, it isn't quite clear if you first have to generate a new CAPTCHA, just to get its key, and then use that key to construct an existing CAPTCHA to create the JPEG. This isn't the case, is it? I could call render on it directly, right?
 
-Yep. it renders directly on this example 'Generate a Captcha' above.
+Yes. it renders directly on this example 'Generate a Captcha' above.
 
 I think there is some confusion in this tutorial because i do 2 things that are a little odd:
 
 	a- i run through the captcha generator to pull a new valid key, this way i can use a new example and have a key validate
 	b- i run through the captcha validator while i can 'guess' an obviously wrong answer.  The way the system is structured, a solution is only provided when you try to validate the captcha.  That is because you might want to 'Render' an existing sound/image captcha which is completely isolated from Validating it.  By purposefully solving it wrong, the routine that sets up the correct user_response is run.
 
+To display a CAPTCHA, you just create a new object and call the render method , passing in a challenge class and render class.  You can call the render method as often as you'd like.  Currently, the module will transparently validate the key in order to render the captcha.
+
 =head3 You actually need to validate the key before check for a correct answer. But couldn't that data be stored on the backend?
 
 Yes,  You could store the data on the backend.  The 'new' constructor will automatically call a key validator so it behaves more like this:
 
   my 	$captcha= new()
-  if ( !$captcha->{'EXPIRED'} && !captcha->{'INVALID'} )
+  if ( !$captcha->EXPIRED && !captcha->INVALID )
   {
   	render
   }
   
-=head3 How would I store the key in the backed?
+=head3 How would I store the key in the backend?
 
 right now, you could either
 
@@ -286,8 +288,15 @@ right now, you could either
 
 or
 
-  create a KeyGenerator subclass, which creates a key and stores it to the db
-  create a KeyValidator subclass which does the db check
+  create a KeyManager subclass, which creates a key and stores it to the db and does the validation
+
+
+=head3 How would I expire the key in the backend?
+
+Good question.  expire_publickey is a method of the captcha and keymanager classes.  expire it in your page logic, or tell the base class to tell the manager to expire it.  but all that code is up to you.
+
+
+
 
 =head3 Things there I don't grok, and so, it is something I kinda feel should be stored on the backend
 
@@ -316,6 +325,41 @@ or
   process that for an answer
 
 
+=head3 I'm still confused on the default public key system (yes, i know i can override it with my own class.  just wondering how yours works )
+
+This might clarify-
+
+  public_key= sprintf "%s:%s" , md5( time , site_secret , seed ) , time
+  time= temporal component that lets a captcha work for only a 5 minute window.  note that is outside of, and inside of, the hash.  this makes the time realistically unspoofably
+  site_secret= non-random seed unique to website to keep spammers from spoofing captcha
+  seed= something unique to build this captcha
+  
+  in my setup:
+
+    $seed= $url . $session{'id'}
+    
+  That makes sure that only 1 captcha is made for a certain URL and a certain session_id ( locked to that time - since the time is used to create the public key,  something 1 second later or earlier would be different )
+  
+  The drawback is that anyone with the same session_id (which can be spoofed / hijacked) can use that same captcha url for the time window
+  
+  If you're comfortable storing session data, this might be better for you:
+
+    $seed= $url . $session{'id'} . $session{'captchas_solved'}
+  
+  Where $session{'captchas_solved'} is undefined at first, but every time a captcha on that session is solved,  session{captchas_solved}++
+
+In the 'equation'/'transaction', the spammer has the URL , the session_id , and the time.  BUT he does not know the site secret, or can control the session variables.
+
+If you've got sessions involved on the page that supports captchas, that approach could probably handle things securely.  It doesn't do a single-ticket expiry, but it pretty much makes it improbable to recreate the conditions to use a captcha more than once.
+
+ 
+=head3 People have problems distinguishing one character for another in my CAPTCHA.  I have the following set (a-z) , how can I implement it?
+
+Create your own challege class and run a filter or create a function that only uses your subset of characters.  This functionality was once provided in the system, but the list of discernable characters became so small it created captchas that were useless.  Depending on the way you render your captcha, the list will change- text/image captchas can render iIl1 similiarly, a warped image will make z2 or 5s  similar- or even 6G 9q. 
+
+Creating your own captcha challenge class, and using it, takes almost no code or time at all to implement (20 lines, maybe? and you can use existing challlenge as a template)
+
+Authen::Pluggable captcha was designed so you can quickly and easily override default functionality like this.
 
 
 =head2 That's it!
